@@ -95,7 +95,7 @@ BEGIN {
       exit;
    }
 
-   our $fa_custom_code='fa_code.pm';
+   # our $fa_custom_code='fa_code.pm';
    # our $fa_menu_config='fa_menu.pm';
 
 }
